// Copyright (C) 2013 File Scribe
// All Rights Reserved.
//
// Use of this code is covered by the "NUMBER DUCK API LICENSE AGREEMENT".
// Details of this agreement are found in the file "licence.txt".
// You have permission to modify this file and use it for any purpose under the terms of
// the agreement.

#ifndef WORKSHEET_H
#define WORKSHEET_H
	#include "Export.h"
	#include <stdint.h>

	namespace FileScribe
	{
		class WorkbookGlobals;
		class Cell;
		class Picture;
		class Chart;
		class Workbook;
		class WorksheetImplementation;
		class Worksheet
		{
			public:
				static const uint16_t MAX_COLUMN = 255;
				static const uint16_t MAX_ROW = 65535;
				static const uint16_t DEFAULT_COLUMN_WIDTH = 64;
				static const uint16_t DEFAULT_ROW_HEIGHT = 20;

				FS_DLL const char* GetName();
				FS_DLL bool SetName(const char* szName);

				FS_DLL uint16_t GetColumnWidth(uint16_t nColumn);
				FS_DLL void SetColumnWidth(uint16_t nColumn, uint16_t nWidth);
				FS_DLL void InsertColumn(uint16_t nColumn);
				FS_DLL void DeleteColumn(uint16_t nColumn);

				FS_DLL uint16_t GetRowHeight(uint16_t nRow);
				FS_DLL void SetRowHeight(uint16_t nRow, uint16_t nHeight);
				FS_DLL void InsertRow(uint16_t nRow);
				FS_DLL void DeleteRow(uint16_t nRow);

				FS_DLL Cell* GetCell(uint16_t nX, uint16_t nY);
				FS_DLL Cell* GetCellByAddress(const char* szAddress);

				FS_DLL uint16_t GetNumPicture();
				FS_DLL Picture* GetPictureByIndex(uint16_t nIndex);
				FS_DLL Picture* CreatePicture(const char* szFileName);
				FS_DLL void PurgePicture(uint16_t nIndex);

				#ifdef FS_CHART
					FS_DLL uint16_t GetNumChart();
					FS_DLL Chart* GetChartByIndex(uint16_t nIndex);
					FS_DLL Chart* CreateChart();
					FS_DLL void PurgeChart(uint16_t nIndex);
				#endif



			protected:
				friend class Workbook;
				friend class Cell;
				friend class Chart;
				Worksheet(Workbook* pWorkbook);
				virtual ~Worksheet();
				WorksheetImplementation* m_pImpl;
		};
	}
#endif